@@ -111,6 +111,13 @@ pub trait ColumnCapabilities<'a> {
         Self: Sized;
 }
 
+/// Null type alias that equals to ()
+pub type SqliteNull = ();
+
+/// An alias to imitate null value for some of the
+/// sqlite3 operations
+pub const SQLITE_NULL: SqliteNull = ();
+
 impl<'a> ColumnCapabilities<'a> for i8 {
     #[inline]
     fn get_data(stmt: *mut sqlite3_stmt, i: usize) -> Result<Self, MinSqliteWrapperError<'a>>
@@ -448,12 +455,12 @@ impl<'a> ColumnCapabilities<'a> for &[u8] {
     }
 }
 
-impl<'a> ColumnCapabilities<'a> for () {
+impl<'a> ColumnCapabilities<'a> for SqliteNull {
     fn get_data(_stmt: *mut sqlite3_stmt, _i: usize) -> Result<Self, MinSqliteWrapperError<'a>>
     where
         Self: Sized,
     {
-        Ok(())
+        unimplemented!()
     }
 
     fn bind_val(self, stmt: *mut sqlite3_stmt, i: usize) -> SqlitePrimaryResult
