@@ -4,5 +4,5 @@
 pub use crate::bindings::SqlitePrimaryResult;
 pub use crate::connection::{Connection, Database};
 pub use crate::ehandle::MinSqliteWrapperError;
-pub use crate::operations::Operations;
+pub use crate::operations::{Operations, SqliteNull, SQLITE_NULL};
 pub use crate::statement::PreparedStatementStatus;
